@@ -1,8 +1,11 @@
-# Copyright (C) 2009 
-# Sebastien Dejean, Institut de Mathematiques, Universite de Toulouse et CNRS (UMR 5219), France
-# Ignacio Gonzelez, Genopole Toulouse Midi-Pyrenees, France
-# Kim-Anh Le Cao, French National Institute for Agricultural Research and 
-# ARC Centre of Excellence ins Bioinformatics, Institute for Molecular Bioscience, University of Queensland, Australia
+#############################################################################################################
+# Authors:
+#   Ignacio Gonzalez, Genopole Toulouse Midi-Pyrenees, France
+#
+# created: 2009
+# last modified:
+#
+# Copyright (C) 2009
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,9 +20,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+#############################################################################################################
 
-
-bin.color <-
+bin.color =
 function(mat, threshold, breaks, col, symkey) 
 {
     if (isTRUE(symkey)) {
@@ -88,7 +91,7 @@ function(mat, threshold, breaks, col, symkey)
     mat[mat < min.breaks] = min.breaks
     mat[mat > max.breaks] = max.breaks
     
-    bin <- .bincode(as.double(mat), as.double(breaks), TRUE, TRUE)
+    bin = .bincode(as.double(mat), as.double(breaks), TRUE, TRUE)
 
     return(invisible(list(bin = bin, col = col, breaks = breaks, lim = c(min.mat, max.mat))))		
 }
